=======
Credits
=======

Development Lead
----------------

* Michael Warkentin <mwarkentin@gmail.com> - https://github.com/mwarkentin - `@mwarkentin <https://twitter.com/mwarkentin>`_

Contributors
------------

* Keryn Knight - https://github.com/kezabelle
* blag - https://github.com/blag
* kilbasar - https://github.com/kilbasar
* Joseph Kahn - https://github.com/JBKahn
* Ben Webber - https://github.com/benwebber
* Michael Fladischer - https://github.com/fladi
* Justin Sacbibit - https://github.com/justinsacbibit
